#
# spec file for package blame
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define origversion 1.4
%define tversion t20240206

Name:           blame
Version:        %{origversion}+%{tversion}
Release:        1.2
Summary:        An RCS file annotator
License:        GPL-2.0-only
Group:          Development/Tools/Version Control
URL:            https://invisible-island.net/rcs-blame/rcs-blame.html
Source:         https://github.com/ThomasDickey/rcs-blame-snapshots/archive/refs/tags/%{tversion}.tar.gz#/rcs-%{name}-snapshots-%{tversion}.tar.gz

%description
Blame displays the last modification for each line in an RCS file.
It is the RCS equivalent of CVS's "annotate" command.

%prep
%autosetup -n rcs-%{name}-snapshots-%{tversion}

%build
%configure
%make_build

%install
%make_install

%check
%make_build check

%files
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1*

%changelog
* Mon Feb 12 2024 Manfred Schwarb <manfred99@gmx.ch>
- update to version 1.4 snapshot t20240206:
  * spelling/documentation fixes
  * support $RCS_DIR for compatibility with cm_tools utilities.
  * make test-suite run from the build-directory rather than the installed copy.
- update to snapshot t20240204:
  * modify top-level makefile to work around pmake's reordering of rules
  * fix a build problem with lib/mktime.c on NetBSD i386
  * modify configure script to permit building with 64-bit time_t on 32-bit system.
  * require standard C, e.g., c89 and later for compiler
  * reduce stricter compiler warnings
- update to snapshot t20240201:
  * fixes to build/work with MacOS and Solaris 10.
- update to snapshot t20240130:
  * build-fixes to work with c11, c23
  * autoconf updates
* Tue Nov  8 2022 Manfred Schwarb <manfred99@gmx.ch>
- update to snapshot t20221108:
  * minor cleanup of README and blame.1
  * add VERSION file
  * config and install-sh updates
* Mon Oct  3 2022 Manfred Schwarb <manfred99@gmx.ch>
- update to snapshot t20220129:
  * configure and makefile updates
* Sun May  2 2021 Manfred Schwarb <manfred99@gmx.ch>
- as the original source location is dead, switch to the repo
    https://github.com/ThomasDickey/rcs-blame-snapshots
- update to version t20210207:
  * several build and code fixes
- remove patch format-security.patch, not needed anymore
* Tue Jun  9 2020 Manfred Schwarb <manfred99@gmx.ch>
- add "-fcommon" for GCC 10
- add %%licence tag in spec file.
- some spec file cleanup
* Sun Jul 31 2016 manfred99@gmx.ch
- fix for -Werror=format-security
  * format-security.patch
* Mon Oct  5 2015 manfred99@gmx.ch
- spec-cleaner changes
- separate changelog file
* Tue Jul 21 2015 manfred99@gmx.ch
- rpm packaging for OBS
* Thu Nov 23 2006 Michael Chapman <foonly@users.sourceforge.net>
- version 1.3.1-1:
  - Gnulib updates.
  - Rebuilt for fc4/fc5/fc6.
* Fri Dec  2 2005 Michael Chapman <foonly@users.sourceforge.net>
- version 1.3-1:
  - Minor bugfixes.
* Thu Jun 30 2005 Michael Chapman <foonly@users.sourceforge.net>
- version 1.2-1:
  - Minor bugfixes.
* Wed Nov 24 2004 Michael Chapman <foonly@users.sourceforge.net>
- version 1.1-1:
  - Rebuilt.
* Wed Nov 24 2004 Michael Chapman <foonly@users.sourceforge.net>
- version 1.0-3:
  - Said gcc 3.4 bugs weren't actually bugs.
* Tue Nov 23 2004 Michael Chapman <foonly@users.sourceforge.net>
- version 1.0-2:
  - Rebuild RPM with -mtune=i386 to work around gcc 3.4 bugs.
* Tue Nov 23 2004 Michael Chapman <foonly@users.sourceforge.net>
- version 1.0-1:
  - Stable release.
* Sat Nov 20 2004 Michael Chapman <foonly@users.sourceforge.net>
- version 0.3-2:
  - Fixed bug involving delta texts without empty last lines.
  - Fixed --help output.
* Thu Nov 11 2004 Michael Chapman <foonly@users.sourceforge.net>
- version 0.3-1:
  - Support for $RCSINIT environment variable.
  - Support for -V and --version to emulate old RCS versions.
  - Minor bugfixes.
  - Added manpage.
* Thu Oct 21 2004 Michael Chapman <foonly@users.sourceforge.net>
- version 0.2-1:
  - Major speed improvements.
* Tue Sep 28 2004 Michael Chapman <foonly@users.sourceforge.net>
- version 0.1-2
  - Fixed build for old Red Hat.
* Mon Sep 27 2004 Michael Chapman <foonly@users.sourceforge.net>
- version 0.1-1:
  - Initial RPM release.
